% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/CST_MultiMetric.R
\name{CST_MultiMetric}
\alias{CST_MultiMetric}
\title{Multiple Metrics applied in Multiple Model Anomalies}
\usage{
CST_MultiMetric(data, metric = "correlation", multimodel = TRUE,
  names = NULL)
}
\arguments{
\item{data}{a CSTools object (list) giving as output of \code{Load} function from S2dverification package.}

\item{metric}{a character string giving the metric for computing the maximum skill. This must be one of the strings 'correlation', 'rms' or 'rmsss.}

\item{multimodel}{a logical value indicating whether a Multi-Model Mean should be computed.}

\item{names}{a character vector indicating the names of the models or experiments to be compared.}
}
\value{
A CSTools object as the input parameter \code{data}, without the elements \code{mod} and \code{obs} and including:
\itemize{
\item\code{$ano_exp} {an array with the same dimensions as the \code{mod} label in the input \code{data}.}
\item\code{$ano_exp} {an array with the same dimensions as the \code{obs} label in the input \code{data}.}
\item\code{$metric} {An array with two datset dimensions from the \code{mod} and \code{obs} label in the input \code{data}. If \code{multimodel} is TRUE, the greatest first dimension correspons to the Multi-Model Mean. The third dimension contains the statistics selected. For metric \code{correlation}, the third dimension is of length four and they corresponds to the lower limit of the 95\% confidence interval, the statistics itselfs, the upper limit of the 95\% confidence interval and the 95\% significance level. For metric \code{rms}, the third dimension is length three and they corresponds to the lower limit of the 95\% confidence interval, the RMSE and the upper limit of the 95\% confidence interval. For metric \code{rmsss}, the third dimension is length two and they corresponds to the statistics itselfs and the p-value of the one-sided Fisher test with Ho: RMSSS = 0.}}
}
\description{
This function calculates correlation (Anomaly Correlation Coefficient; ACC), root mean square error (RMS) and the root mean square error skill score (RMSSS) of individual anomaly models and multi-models mean (if desired) with the observations.
}
\details{
The output will include attributes in element \code{ano_exp} returning a vector with the names of the models or experiments.
}
\examples{
mod <- 1 : (2 * 3 * 4 * 5 * 6 * 7)
dim(mod) <- c(dataset = 2, member = 3, sdate = 4, ftime = 5, lat = 6, lon = 7)
obs <- 1 : (1 * 1 * 4 * 5 * 6 * 7)
dim(obs) <- c(dataset = 1, member = 1, sdate = 4, ftime = 5, lat = 6, lon = 7)
lon <- seq(0, 30, 5)
lat <- seq(0, 25, 5)
dat <- list(mod = mod, obs = obs, lat = lat, lon = lon)
a <- CST_MultiMetric(dat)
str(a)
}
\references{
\url{http://link.springer.com/10.1007/s00382-018-4404-z}
}
\seealso{
\code{\link[s2dverification]{Corr}}, \code{\link[s2dverification]{RMS}}, \code{\link[s2dverification]{RMSSS}} and \code{\link[s2dverification]{Load}}
}
\author{
Mishra Niti, \email{niti.mishra@bsc.es}

Perez-Zanon Nuria, \email{nuria.perez@bsc.es}
}
